@@ -53,13 +53,4 @@ abstract class Schema extends Attribute
 			$key,
 			$key === 'title' ? $string : __('No description available, can you help with one?'));
 	}
-
-	public function render(string $attrtag,int $index,bool $edit=FALSE,bool $editable=FALSE,bool $new=FALSE,bool $updated=FALSE,?Template $template=NULL): View
-	{
-		// @note Schema attributes cannot be edited
-		return view('components.attribute.schema.generic')
-			->with('o',$this)
-			->with('dotkey',$dotkey=$this->dotkey($attrtag,$index))
-			->with('value',$this->render_item_new($dotkey));
-	}
 }
\ No newline at end of file
