@@ -89,9 +89,9 @@ class Template
 		return match ($key) {
 			'attributes','objectclasses' => collect($this->template->get($key)),
 			'enabled' => $this->template->get($key,FALSE) && (! $this->invalid),
-			'icon','regexp','title' => $this->template->get($key),
+			'icon','rdn','regexp','title' => $this->template->get($key),
 			'name' => Str::replaceEnd('.json','',$this->file),
-			'order' => $this->attributes->map(fn($item)=>Arr::get($item,'order')),
+			'order' => $this->attributes->flatMap(fn($item,$key)=>[strtolower($key)=>Arr::get($item,'order')]),
 
 			default => throw new \Exception('Unknown key: '.$key),
 		};
@@ -110,12 +110,14 @@ class Template
 	 */
 	public function attribute(string $attribute): Collection|NULL
 	{
-		$key = $this->attributes->search(fn($item,$key)=>! strcasecmp($key,$attribute));
+		$key = $this->attributes
+			->search(fn($item,$key)=>! strcasecmp($key,$attribute));
+
 		return collect($this->attributes->get($key));
 	}
 
 	/**
-	 * Return an template attributes select options
+	 * Return a template attributes select options
 	 *
 	 * @param string $attribute
 	 * @return Collection|NULL
@@ -316,6 +318,17 @@ class Template
 			: NULL;
 	}
 
+	/**
+	 * Return if an attribute is automatically calculated
+	 *
+	 * @param $attribute
+	 * @return bool
+	 */
+	public function isAttributeCalculated($attribute): bool
+	{
+		return preg_match('/^=([a-zA-Z]+)/',$this->attribute($attribute)->get('value'));
+	}
+
 	/**
 	 * Return the onChange JavaScript for an attribute
 	 *
