@@ -2,7 +2,6 @@
 
 namespace App\Providers;
 
-use Illuminate\Support\Collection;
 use Illuminate\Support\ServiceProvider;
 use LdapRecord\Configuration\DomainConfiguration;
 use LdapRecord\Laravel\LdapRecord;
@@ -29,11 +28,5 @@ class AppServiceProvider extends ServiceProvider
 	public function boot(): void
 	{
 		$this->loadViewsFrom(__DIR__.'/../../resources/themes/architect/views/','architect');
-
-		// Enable pluck on collections to work on private values
-		Collection::macro('ppluck',
-			fn($attr)=>$this
-				->map(fn($item)=>$item->{$attr})
-				->values());
 	}
 }
\ No newline at end of file
