@@ -21,13 +21,13 @@ class CertificateIsBinary implements ValidationRule
     public function validate(string $attribute,mixed $value,Closure $fail): void
     {
 		foreach (collect($value)->dot() as $item) {
-
 			try {
 				openssl_x509_read($item);
 
 			} catch (\ErrorException $e) {
+				\Log::error('CIB: openssl_x509_read failed with :'.$e->getMessage());
 				$fail(__('This is not a valid certificate: '.$e->getMessage()));
-				return;
+				break;
 			}
 		}
     }
