@@ -6,7 +6,11 @@
 
 			@foreach($o->attrs->map(fn($item)=>['id'=>$item,'value'=>$item]) as $option)
 				@continue(! Arr::get($option,'value'))
-				<option value="{{ strtolower(Arr::get($option,'id')) }}" @selected(Arr::get($option,'id') == old('_rdn',$o->rdn_attr))>{{ Arr::get($option,'value') }}</option>
+				<option
+					value="{{ strtolower(Arr::get($option,'id')) }}"
+					@selected(Arr::get($option,'id') == old('_rdn',$o->rdn_attr ?: $template?->rdn))>
+					{{ Arr::get($option,'value') }}
+				</option>
 			@endforeach
 		</select>
 
@@ -40,29 +44,36 @@
 			rdn_attr = $('select#rdn').val();
 
 			if (rdn_attr) {
-				$('#'+rdn_attr).find('input').first().attr('readonly',true);
+				$('#'+rdn_attr+' input:first')
+					.attr('readonly',true);
+
 				set_rdn_value();
 			}
 
 			function set_rdn_value() {
 				if (rdn_attr && rdn_value_set)
-					$('#'+rdn_attr).find('input').first().val($('input#rdn_value').val());
+					$('#'+rdn_attr+' input:first')
+						.val($('input#rdn_value').val());
 			}
 
 			$('select#rdn').on('change',function() {
 				// If the selected attr has a value, use it
-				var rdn_value = $(this).val() ? $('#'+$(this).val()).find('input').first().val() : null;
+				var rdn_value = $(this).val()
+					? $('#'+$(this).val()+' input:first').val()
+					: null;
 
 				if (rdn_value)
 					$('input#rdn_value').val(rdn_value);
 
 				// if rdn_attr is already set (and its now different), remove read only and clear value
 				if (rdn_attr)
-					$('#'+rdn_attr).find('input').first().attr('readonly',false).val('');
+					$('#'+rdn_attr+' input:first')
+						.attr('readonly',false).val('');
 
 				// set RDN attribute read-only
 				if ((rdn_attr=$(this).val()) && rdn_attr)
-					$('#'+rdn_attr).find('input').first().attr('readonly',true);
+					$('#'+rdn_attr+' input:first')
+						.attr('readonly',true);
 
 				set_rdn_value();
 			})
