@@ -1,9 +1,9 @@
-@extends('layouts.dn')
+@extends('layouts.frame')
 
 @section('page_title')
 	<table class="table table-borderless">
 		<tr>
-			<td style="border-radius: 5px;"><div class="page-title-icon f32"><i class="fas fa-fingerprint"></i></div></td>
+			<td><div class="page-title-icon f32"><i class="fas fa-fingerprint"></i></div></td>
 			<td class="top text-end align-text-top p-2"><strong>{{ $server->schemaDN() }}</strong></td>
 		</tr>
 	</table>
@@ -50,9 +50,10 @@
 		var loaded = [];
 
 		$(document).ready(function() {
-			$('a[data-bs-toggle="tab"]').on('shown.bs.tab', function (item) {
+			$('a[data-bs-toggle="tab"]').on('shown.bs.tab',function(item) {
 				// activated tab
 				var type = $(item.target).attr('href').substring(1);
+
 				if (loaded[type])
 					return false;
 
@@ -66,9 +67,7 @@
 					$('div[id="schema.'+type+'"]').empty().append(html);
 					loaded[type] = true;
 
-				}).fail(function() {
-					alert('Failed');
-				});
+				}).fail(ajax_error);
 
 				item.stopPropagation();
 			});
